# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API ClickAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8f>`_
"""

BOOKMARK: 'uno.Enum'
"""
The presentation jumps to a bookmark.
"""
DOCUMENT: 'uno.Enum'
"""
The presentation jumps to another document.
"""
FIRSTPAGE: 'uno.Enum'
"""
The presentation continues with the first page.
"""
INVISIBLE: 'uno.Enum'
"""
The object renders itself invisible after a click.
"""
LASTPAGE: 'uno.Enum'
"""
The presentation continues with the last page.
"""
MACRO: 'uno.Enum'
"""
A star basic macro is executed after the click.
"""
NEXTPAGE: 'uno.Enum'
"""
The presentation jumps to the next page.
"""
NONE: 'uno.Enum'
"""
use no animation effects.

use no fade effects.

No action is performed on click.
"""
PREVPAGE: 'uno.Enum'
"""
The presentation jumps to the previous page.
"""
PROGRAM: 'uno.Enum'
"""
Another program is executed after a click.
"""
SOUND: 'uno.Enum'
"""
A sound is played after a click.
"""
STOPPRESENTATION: 'uno.Enum'
"""
The presentation is stopped after the click.
"""
VANISH: 'uno.Enum'
"""
The object vanishes with its effect.
"""
VERB: 'uno.Enum'
"""
An OLE verb is performed on this object.
"""

