# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from .ole_bridge_supplier2 import OleBridgeSupplier2 as OleBridgeSupplier2_18030e68

class OleBridgeSupplierVar1(OleBridgeSupplier2_18030e68):
    """
    Service Class

    maps UNO types to COM types and vice versa.
    
    It is optimized for use in a remote scenario.
    
    The functionality is basically the same as com.sun.star.bridge.OleBridgeSupplier2. However, the implementation should be optimized for remote access. For example, it could try to reduce the calls into the remote process. Also it could create components on its own behalf in the remote process, if this increases performance.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API OleBridgeSupplierVar1 <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1OleBridgeSupplierVar1.html>`_
    """


