# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.beans
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XPropertyContainer(XInterface_8f010a43):
    """
    makes it possible to add and remove properties to or from an object.
    
    Some scripting engines cannot access properties directly when the property set is changed. Please use XPropertySet.getPropertyValue() etc. in this case.

    See Also:
        `API XPropertyContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertyContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.beans.XPropertyContainer']

    def addProperty(self, Name: str, Attributes: int, DefaultValue: object) -> None:
        """
        adds a property to the object.

        Raises:
            com.sun.star.beans.PropertyExistException: ``PropertyExistException``
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removeProperty(self, Name: str) -> None:
        """
        removes a property from the object.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.NotRemoveableException: ``NotRemoveableException``
        """

