# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from ..sdbc.x_driver_manager import XDriverManager as XDriverManager_c6470c23
if typing.TYPE_CHECKING:
    from .x_database_access import XDatabaseAccess as XDatabaseAccess_c47a0c00

class XDatabaseEnvironment(XDriverManager_c6470c23):
    """
    is not to be used anymore.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDatabaseEnvironment <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseEnvironment.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XDatabaseEnvironment']

    def createDatabaseAccess(self, URL: str, title: str) -> 'XDatabaseAccess_c47a0c00':
        """

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getDatabaseAccess(self, URL: str) -> 'XDatabaseAccess_c47a0c00':
        """

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """

