# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..uno.x_aggregation import XAggregation as XAggregation_a4230b1a

class XProxyFactory(XInterface_8f010a43):
    """
    Factory interface to produce proxy objects.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XProxyFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XProxyFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XProxyFactory']

    def createProxy(self, xTarget: 'XInterface_8f010a43') -> 'XAggregation_a4230b1a':
        """
        This method creates a new proxy object that acts on behalf of the given target object.
        
        The proxy delegates calls to the given target object. In addition, it is aggregatable, thus it is possible to intercept calls on the proxy's interfaces.
        """

