# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
from .x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b

class XAccessibleContext2(XAccessibleContext_8eae119b):
    """
    Implement this interface for exposing more aspects of a class's content.
    
    This is an extension of XAccessibleContext to add getAccessibleId().
    
    **since**
    
        LibreOffice 6.3

    See Also:
        `API XAccessibleContext2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleContext2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleContext2']

    def getAccessibleId(self) -> str:
        """
        Return the object's identifier.
        
        This is not meant to be presented to the user, but to be an ID which is stable over application development. Typically, this is the gtkbuilder ID. Such an ID can then be used to identify a given well-known accessible object independently from the current locale, user-visible labelling, or dialog structure. This can then be used for tailored screen reading (e.g. automatically announcing the content of a well-known object), or for automatic regression testing (to check the behavior of well-known objects). Uniqueness within the window is thus desirable when returning a non-empty string.
        """

