# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class DateDisplayFormat(object):
    """
    Const

    This constants define how a date field is formatted before it is displayed.
    
    The format may also depend on the system or document locale. The samples are in German.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DateDisplayFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html>`_
    """
    STANDARD_SHORT: Literal[0]
    """
    the shortest system standard
    """
    STANDARD_LONG: Literal[1]
    """
    the longest system standard
    """
    MMDDYY: Literal[2]
    """
    22.11.73
    """
    MMDDYYYY: Literal[3]
    """
    22.11.1973
    """
    DDMMMYYYY: Literal[4]
    DDMMMMYYYY: Literal[5]
    NNDDMMMMYYYY: Literal[6]
    """
    Do, 22.
    
    November 1973
    """
    NNNNDDMMMMYYYY: Literal[7]
    """
    Donnerstag, 22.
    
    November 1973
    """

