# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
from .x_animate import XAnimate as XAnimate_ca680c52

class XAnimateColor(XAnimate_ca680c52):
    """
    Interface for animation by defining color changes over time.
    
    Only color value will be legal values for the following members

    See Also:
        `API XAnimateColor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimateColor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XAnimateColor']

    @property
    def ColorInterpolation(self) -> int:
        """
        defines the color space which is used to perform the interpolation.
        """

    @property
    def Direction(self) -> bool:
        """
        defines the direction which is used to perform the interpolation inside the color space defined with ColorInterpolation.
        
        Values could be TRUE for clockwise and FALSE for counterclockwise.
        
        This attribute will be ignored for color spaces where this does not make any sense.
        """


