# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.media
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum

ENUM ZoomLevel

See Also:
    `API ZoomLevel <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1media.html#aa2569917c2883c1d1c0c0ee02e671ac6>`_
"""

FIT_TO_WINDOW: 'uno.Enum'
"""
specifies that the video should be zoomed to window size
"""
FIT_TO_WINDOW_FIXED_ASPECT: 'uno.Enum'
"""
specifies that the video should be zoomed to window size with using a fixed aspect ratio
"""
FULLSCREEN: 'uno.Enum'
"""
specifies that the video should be displayed in fullscreen mode, if available
"""
NOT_AVAILABLE: 'uno.Enum'
"""
specifies that the video window itself is not available at all, e.g.

in cases of pure audio playback
"""
ORIGINAL: 'uno.Enum'
"""
specifies that the video should be displayed with its original size
"""
ZOOM_1_TO_2: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 1:2
"""
ZOOM_1_TO_4: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 1:4
"""
ZOOM_2_TO_1: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 2:1
"""
ZOOM_4_TO_1: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 4:1
"""

