# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.text.accessible_endnote_view import AccessibleEndnoteView as AccessibleEndnoteView
from .._pyi.text.accessible_footnote_view import AccessibleFootnoteView as AccessibleFootnoteView
from .._pyi.text.accessible_header_footer_view import AccessibleHeaderFooterView as AccessibleHeaderFooterView
from .._pyi.text.accessible_page_view import AccessiblePageView as AccessiblePageView
from .._pyi.text.accessible_paragraph_view import AccessibleParagraphView as AccessibleParagraphView
from .._pyi.text.accessible_text_document_page_view import AccessibleTextDocumentPageView as AccessibleTextDocumentPageView
from .._pyi.text.accessible_text_document_view import AccessibleTextDocumentView as AccessibleTextDocumentView
from .._pyi.text.accessible_text_embedded_object import AccessibleTextEmbeddedObject as AccessibleTextEmbeddedObject
from .._pyi.text.accessible_text_frame_view import AccessibleTextFrameView as AccessibleTextFrameView
from .._pyi.text.accessible_text_graphic_object import AccessibleTextGraphicObject as AccessibleTextGraphicObject
from .._pyi.text.auto_text_container import AutoTextContainer as AutoTextContainer
from .._pyi.text.auto_text_entry import AutoTextEntry as AutoTextEntry
from .._pyi.text.auto_text_group import AutoTextGroup as AutoTextGroup
from .._pyi.text.base_frame import BaseFrame as BaseFrame
from .._pyi.text.base_frame_properties import BaseFrameProperties as BaseFrameProperties
from .._pyi.text.base_index import BaseIndex as BaseIndex
from .._pyi.text.base_index_mark import BaseIndexMark as BaseIndexMark
from .._pyi.text.bibliography import Bibliography as Bibliography
from .._pyi.text.bookmark import Bookmark as Bookmark
from .._pyi.text.bookmarks import Bookmarks as Bookmarks
from .._pyi.text.cell import Cell as Cell
from .._pyi.text.cell_properties import CellProperties as CellProperties
from .._pyi.text.cell_range import CellRange as CellRange
from .._pyi.text.chained_text_frame import ChainedTextFrame as ChainedTextFrame
from .._pyi.text.chapter_numbering_rule import ChapterNumberingRule as ChapterNumberingRule
from .._pyi.text.content_index import ContentIndex as ContentIndex
from .._pyi.text.content_index_mark import ContentIndexMark as ContentIndexMark
from .._pyi.text.default_numbering_provider import DefaultNumberingProvider as DefaultNumberingProvider
from .._pyi.text.defaults import Defaults as Defaults
from .._pyi.text.dependent_text_field import DependentTextField as DependentTextField
from .._pyi.text.document_index import DocumentIndex as DocumentIndex
from .._pyi.text.document_index_level_format import DocumentIndexLevelFormat as DocumentIndexLevelFormat
from .._pyi.text.document_index_mark import DocumentIndexMark as DocumentIndexMark
from .._pyi.text.document_index_mark_asian import DocumentIndexMarkAsian as DocumentIndexMarkAsian
from .._pyi.text.document_index_paragraph_styles import DocumentIndexParagraphStyles as DocumentIndexParagraphStyles
from .._pyi.text.document_indexes import DocumentIndexes as DocumentIndexes
from .._pyi.text.document_settings import DocumentSettings as DocumentSettings
from .._pyi.text.endnote import Endnote as Endnote
from .._pyi.text.endnote_settings import EndnoteSettings as EndnoteSettings
from .._pyi.text.footnote import Footnote as Footnote
from .._pyi.text.footnote_settings import FootnoteSettings as FootnoteSettings
from .._pyi.text.footnotes import Footnotes as Footnotes
from .._pyi.text.generic_text_document import GenericTextDocument as GenericTextDocument
from .._pyi.text.global_document import GlobalDocument as GlobalDocument
from .._pyi.text.global_settings import GlobalSettings as GlobalSettings
from .._pyi.text.graphic_crop import GraphicCrop as GraphicCrop
from .._pyi.text.hori_orientation_format import HoriOrientationFormat as HoriOrientationFormat
from .._pyi.text.illustrations_index import IllustrationsIndex as IllustrationsIndex
from .._pyi.text.in_content_metadata import InContentMetadata as InContentMetadata
from .._pyi.text.invalid_text_content_exception import InvalidTextContentException as InvalidTextContentException
from .._pyi.text.line_numbering_properties import LineNumberingProperties as LineNumberingProperties
from .._pyi.text.mail_merge import MailMerge as MailMerge
from .._pyi.text.mail_merge_event import MailMergeEvent as MailMergeEvent
from .._pyi.text.module_dispatcher import ModuleDispatcher as ModuleDispatcher
from .._pyi.text.numbering_level import NumberingLevel as NumberingLevel
from .._pyi.text.numbering_rules import NumberingRules as NumberingRules
from .._pyi.text.numbering_style import NumberingStyle as NumberingStyle
from .._pyi.text.object_index import ObjectIndex as ObjectIndex
from .._pyi.text.page_footnote_info import PageFootnoteInfo as PageFootnoteInfo
from .._pyi.text.page_print_settings import PagePrintSettings as PagePrintSettings
from .._pyi.text.paragraph import Paragraph as Paragraph
from .._pyi.text.paragraph_enumeration import ParagraphEnumeration as ParagraphEnumeration
from .._pyi.text.print_settings import PrintSettings as PrintSettings
from .._pyi.text.redline_portion import RedlinePortion as RedlinePortion
from .._pyi.text.reference_mark import ReferenceMark as ReferenceMark
from .._pyi.text.reference_marks import ReferenceMarks as ReferenceMarks
from .._pyi.text.section_file_link import SectionFileLink as SectionFileLink
from .._pyi.text.shape import Shape as Shape
from .._pyi.text.table_column_separator import TableColumnSeparator as TableColumnSeparator
from .._pyi.text.table_columns import TableColumns as TableColumns
from .._pyi.text.table_index import TableIndex as TableIndex
from .._pyi.text.table_rows import TableRows as TableRows
from .._pyi.text.text import Text as Text
from .._pyi.text.text_column import TextColumn as TextColumn
from .._pyi.text.text_column_sequence import TextColumnSequence as TextColumnSequence
from .._pyi.text.text_columns import TextColumns as TextColumns
from .._pyi.text.text_content import TextContent as TextContent
from .._pyi.text.text_content_collection import TextContentCollection as TextContentCollection
from .._pyi.text.text_cursor import TextCursor as TextCursor
from .._pyi.text.text_document import TextDocument as TextDocument
from .._pyi.text.text_document_view import TextDocumentView as TextDocumentView
from .._pyi.text.text_embedded_object import TextEmbeddedObject as TextEmbeddedObject
from .._pyi.text.text_embedded_objects import TextEmbeddedObjects as TextEmbeddedObjects
from .._pyi.text.text_field import TextField as TextField
from .._pyi.text.text_field_enumeration import TextFieldEnumeration as TextFieldEnumeration
from .._pyi.text.text_field_master import TextFieldMaster as TextFieldMaster
from .._pyi.text.text_field_masters import TextFieldMasters as TextFieldMasters
from .._pyi.text.text_fields import TextFields as TextFields
from .._pyi.text.text_frame import TextFrame as TextFrame
from .._pyi.text.text_frames import TextFrames as TextFrames
from .._pyi.text.text_graphic_object import TextGraphicObject as TextGraphicObject
from .._pyi.text.text_graphic_objects import TextGraphicObjects as TextGraphicObjects
from .._pyi.text.text_layout_cursor import TextLayoutCursor as TextLayoutCursor
from .._pyi.text.text_markup_descriptor import TextMarkupDescriptor as TextMarkupDescriptor
from .._pyi.text.text_page_style import TextPageStyle as TextPageStyle
from .._pyi.text.text_portion import TextPortion as TextPortion
from .._pyi.text.text_portion_enumeration import TextPortionEnumeration as TextPortionEnumeration
from .._pyi.text.text_position import TextPosition as TextPosition
from .._pyi.text.text_range import TextRange as TextRange
from .._pyi.text.text_range_content_properties import TextRangeContentProperties as TextRangeContentProperties
from .._pyi.text.text_range_selection import TextRangeSelection as TextRangeSelection
from .._pyi.text.text_ranges import TextRanges as TextRanges
from .._pyi.text.text_section import TextSection as TextSection
from .._pyi.text.text_sections import TextSections as TextSections
from .._pyi.text.text_sort_descriptor import TextSortDescriptor as TextSortDescriptor
from .._pyi.text.text_sort_descriptor2 import TextSortDescriptor2 as TextSortDescriptor2
from .._pyi.text.text_sortable import TextSortable as TextSortable
from .._pyi.text.text_table import TextTable as TextTable
from .._pyi.text.text_table_cursor import TextTableCursor as TextTableCursor
from .._pyi.text.text_table_row import TextTableRow as TextTableRow
from .._pyi.text.text_tables import TextTables as TextTables
from .._pyi.text.text_view_cursor import TextViewCursor as TextViewCursor
from .._pyi.text.user_defined_index import UserDefinedIndex as UserDefinedIndex
from .._pyi.text.user_index import UserIndex as UserIndex
from .._pyi.text.user_index_mark import UserIndexMark as UserIndexMark
from .._pyi.text.vert_orientation_format import VertOrientationFormat as VertOrientationFormat
from .._pyi.text.view_settings import ViewSettings as ViewSettings
from .._pyi.text.web_document import WebDocument as WebDocument
from .._pyi.text.x_auto_text_container import XAutoTextContainer as XAutoTextContainer
from .._pyi.text.x_auto_text_container2 import XAutoTextContainer2 as XAutoTextContainer2
from .._pyi.text.x_auto_text_entry import XAutoTextEntry as XAutoTextEntry
from .._pyi.text.x_auto_text_group import XAutoTextGroup as XAutoTextGroup
from .._pyi.text.x_bookmark_insert_tool import XBookmarkInsertTool as XBookmarkInsertTool
from .._pyi.text.x_bookmarks_supplier import XBookmarksSupplier as XBookmarksSupplier
from .._pyi.text.x_chapter_numbering_supplier import XChapterNumberingSupplier as XChapterNumberingSupplier
from .._pyi.text.x_default_numbering_provider import XDefaultNumberingProvider as XDefaultNumberingProvider
from .._pyi.text.x_dependent_text_field import XDependentTextField as XDependentTextField
from .._pyi.text.x_document_index import XDocumentIndex as XDocumentIndex
from .._pyi.text.x_document_index_mark import XDocumentIndexMark as XDocumentIndexMark
from .._pyi.text.x_document_indexes_supplier import XDocumentIndexesSupplier as XDocumentIndexesSupplier
from .._pyi.text.x_endnotes_settings_supplier import XEndnotesSettingsSupplier as XEndnotesSettingsSupplier
from .._pyi.text.x_endnotes_supplier import XEndnotesSupplier as XEndnotesSupplier
from .._pyi.text.x_flat_paragraph import XFlatParagraph as XFlatParagraph
from .._pyi.text.x_flat_paragraph_iterator import XFlatParagraphIterator as XFlatParagraphIterator
from .._pyi.text.x_flat_paragraph_iterator_provider import XFlatParagraphIteratorProvider as XFlatParagraphIteratorProvider
from .._pyi.text.x_footnote import XFootnote as XFootnote
from .._pyi.text.x_footnotes_settings_supplier import XFootnotesSettingsSupplier as XFootnotesSettingsSupplier
from .._pyi.text.x_footnotes_supplier import XFootnotesSupplier as XFootnotesSupplier
from .._pyi.text.x_form_field import XFormField as XFormField
from .._pyi.text.x_line_numbering_properties import XLineNumberingProperties as XLineNumberingProperties
from .._pyi.text.x_mail_merge_broadcaster import XMailMergeBroadcaster as XMailMergeBroadcaster
from .._pyi.text.x_mail_merge_listener import XMailMergeListener as XMailMergeListener
from .._pyi.text.x_marking_access import XMarkingAccess as XMarkingAccess
from .._pyi.text.x_multi_text_markup import XMultiTextMarkup as XMultiTextMarkup
from .._pyi.text.x_numbering_formatter import XNumberingFormatter as XNumberingFormatter
from .._pyi.text.x_numbering_rules_supplier import XNumberingRulesSupplier as XNumberingRulesSupplier
from .._pyi.text.x_numbering_type_info import XNumberingTypeInfo as XNumberingTypeInfo
from .._pyi.text.x_page_cursor import XPageCursor as XPageCursor
from .._pyi.text.x_page_printable import XPagePrintable as XPagePrintable
from .._pyi.text.x_paragraph_append import XParagraphAppend as XParagraphAppend
from .._pyi.text.x_paragraph_cursor import XParagraphCursor as XParagraphCursor
from .._pyi.text.x_paste_broadcaster import XPasteBroadcaster as XPasteBroadcaster
from .._pyi.text.x_paste_listener import XPasteListener as XPasteListener
from .._pyi.text.x_redline import XRedline as XRedline
from .._pyi.text.x_reference_marks_supplier import XReferenceMarksSupplier as XReferenceMarksSupplier
from .._pyi.text.x_relative_text_content_insert import XRelativeTextContentInsert as XRelativeTextContentInsert
from .._pyi.text.x_relative_text_content_remove import XRelativeTextContentRemove as XRelativeTextContentRemove
from .._pyi.text.x_ruby_selection import XRubySelection as XRubySelection
from .._pyi.text.x_sentence_cursor import XSentenceCursor as XSentenceCursor
from .._pyi.text.x_simple_text import XSimpleText as XSimpleText
from .._pyi.text.x_text import XText as XText
from .._pyi.text.x_text_append import XTextAppend as XTextAppend
from .._pyi.text.x_text_append_and_convert import XTextAppendAndConvert as XTextAppendAndConvert
from .._pyi.text.x_text_columns import XTextColumns as XTextColumns
from .._pyi.text.x_text_content import XTextContent as XTextContent
from .._pyi.text.x_text_content_append import XTextContentAppend as XTextContentAppend
from .._pyi.text.x_text_convert import XTextConvert as XTextConvert
from .._pyi.text.x_text_copy import XTextCopy as XTextCopy
from .._pyi.text.x_text_cursor import XTextCursor as XTextCursor
from .._pyi.text.x_text_document import XTextDocument as XTextDocument
from .._pyi.text.x_text_embedded_objects_supplier import XTextEmbeddedObjectsSupplier as XTextEmbeddedObjectsSupplier
from .._pyi.text.x_text_field import XTextField as XTextField
from .._pyi.text.x_text_fields_supplier import XTextFieldsSupplier as XTextFieldsSupplier
from .._pyi.text.x_text_frame import XTextFrame as XTextFrame
from .._pyi.text.x_text_frames_supplier import XTextFramesSupplier as XTextFramesSupplier
from .._pyi.text.x_text_graphic_objects_supplier import XTextGraphicObjectsSupplier as XTextGraphicObjectsSupplier
from .._pyi.text.x_text_markup import XTextMarkup as XTextMarkup
from .._pyi.text.x_text_portion_append import XTextPortionAppend as XTextPortionAppend
from .._pyi.text.x_text_range import XTextRange as XTextRange
from .._pyi.text.x_text_range_compare import XTextRangeCompare as XTextRangeCompare
from .._pyi.text.x_text_range_mover import XTextRangeMover as XTextRangeMover
from .._pyi.text.x_text_section import XTextSection as XTextSection
from .._pyi.text.x_text_sections_supplier import XTextSectionsSupplier as XTextSectionsSupplier
from .._pyi.text.x_text_shapes_supplier import XTextShapesSupplier as XTextShapesSupplier
from .._pyi.text.x_text_table import XTextTable as XTextTable
from .._pyi.text.x_text_table_cursor import XTextTableCursor as XTextTableCursor
from .._pyi.text.x_text_tables_supplier import XTextTablesSupplier as XTextTablesSupplier
from .._pyi.text.x_text_view_cursor import XTextViewCursor as XTextViewCursor
from .._pyi.text.x_text_view_cursor_supplier import XTextViewCursorSupplier as XTextViewCursorSupplier
from .._pyi.text.x_text_view_text_range_supplier import XTextViewTextRangeSupplier as XTextViewTextRangeSupplier
from .._pyi.text.x_word_cursor import XWordCursor as XWordCursor
