# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.io
from .x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_markable_stream import XMarkableStream as XMarkableStream_b9bc0bc3
from .x_object_input_stream import XObjectInputStream as XObjectInputStream_dfb60d0b

class ObjectInputStream(XActiveDataSink_b8d00ba3, XConnectable_980a0a96, XMarkableStream_b9bc0bc3, XObjectInputStream_dfb60d0b):
    """
    Service Class

    is a stream which allows reading the data of persistent objects.
    
    Implementations of this service must fulfill the specifications of the DataInputStream service. It must be chained to an XMarkableStream. Therefore, it provides the XMarkableStream interface, and delegates the calls to the chained object.
    
    The written objects are held until this instance is destroyed. The references to the objects are read as four-byte integers. Data format reads:

    See Also:
        `API ObjectInputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1ObjectInputStream.html>`_
    """


