# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
"""
Const

These are the possible values for Rule.Action.

See Also:
    `API RuleAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1RuleAction.html>`_
"""
NONE: Literal[0]
"""
\"None\" - Do nothing.
"""
SHOW: Literal[1]
"""
\"Show\" - Shows object when term matches.
"""
HIDE: Literal[2]
"""
\"Hide\" - Hides object when term matches.
"""
MARK: Literal[3]
"""
\"Mark\" - Marks object when term matches.
"""
UNMARK: Literal[4]
"""
\"UnMark\" - Removes mark from object when term matches.
"""
MARKREAD: Literal[5]
"""
\"MarkRead\" - Marks object as read when term matches.
"""
MARKUNREAD: Literal[6]
"""
\"MarkUnRead\" - Marks object as not read when term matches.
"""
MOVE: Literal[7]
"""
\"Move\" - Moves object to Rule.Parameter when term matches.
"""
COPY: Literal[8]
"""
\"Copy\" - Copies object to Rule.Parameter when term matches.
"""
DELETE: Literal[9]
"""
\"Delete\" - Deletes object when term matches.
"""
LINK: Literal[10]
"""
\"Link\" - Creates a link to Rule.Parameter when term matches.
"""
FORWARD: Literal[11]
"""
\"Forward\" - Forwards object to Rule.Parameter when term matches.
"""

