# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from .x_parameters_supplier import XParametersSupplier as XParametersSupplier_fc7c0e01
from .x_single_select_query_analyzer import XSingleSelectQueryAnalyzer as XSingleSelectQueryAnalyzer_66ad10b7
from ..sdbcx.x_columns_supplier import XColumnsSupplier as XColumnsSupplier_f0600da9
from ..sdbcx.x_tables_supplier import XTablesSupplier as XTablesSupplier_e1ad0d23

class SingleSelectQueryAnalyzer(XParametersSupplier_fc7c0e01, XSingleSelectQueryAnalyzer_66ad10b7, XColumnsSupplier_f0600da9, XTablesSupplier_e1ad0d23):
    """
    Service Class

    represents a service for analyzing a single select statement.
    
    It hides the complexity of parsing and evaluating a single select statement and provides sophisticated methods for accessing a statements filter, group by, having and order criteria, as well as the corresponding select columns and tables. If supported, it even gives access to the parameters.

    See Also:
        `API SingleSelectQueryAnalyzer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1SingleSelectQueryAnalyzer.html>`_
    """


