# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class Weekdays(object):
    """
    Const

    Constants for days of a week.
    
    used with XCalendar.getFirstDayOfWeek(), XCalendar.setFirstDayOfWeek() and XCalendar.getDisplayName()

    See Also:
        `API Weekdays <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1Weekdays.html>`_
    """
    SUNDAY: Literal[0]
    """
    Sunday.
    """
    MONDAY: Literal[1]
    """
    Monday.
    """
    TUESDAY: Literal[2]
    """
    Tuesday.
    """
    WEDNESDAY: Literal[3]
    """
    Wednesday.
    """
    THURSDAY: Literal[4]
    """
    Thursday.
    """
    FRIDAY: Literal[5]
    """
    Friday.
    """
    SATURDAY: Literal[6]
    """
    Saturday.
    """

