# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from .x_bridge_supplier import XBridgeSupplier as XBridgeSupplier_ede00d6e

class OleBridgeSupplier(XBridgeSupplier_ede00d6e):
    """
    Service Class

    makes it possible to generate OLE bridges to UNO objects and vice versa.
    
    The service implements the XBridgeSupplier interface and handles the model types ModelDependent.UNO and ModelDependent.OLE. The service does not specify any requirements on registering OLE objects and class factories.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API OleBridgeSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1OleBridgeSupplier.html>`_
    """


