# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.container
from typing_extensions import Literal
import typing
from .x_element_access import XElementAccess as XElementAccess_cd60e3f

class XIdentifierAccess(XElementAccess_cd60e3f):
    """
    provides access to the elements of a collection through a unique identifier.

    See Also:
        `API XIdentifierAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XIdentifierAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.container.XIdentifierAccess']

    def getByIdentifier(self, Identifier: int) -> object:
        """

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def getIdentifiers(self) -> 'typing.Tuple[int, ...]':
        """
        The order of the identifiers is not specified.
        """

