# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class FontUnderline(object):
    """
    Const

    These values are used to specify the kind of underlining.
    
    They may be expanded in future versions.

    See Also:
        `API FontUnderline <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontUnderline.html>`_
    """
    NONE: Literal[0]
    """
    specifies no underlining.
    """
    SINGLE: Literal[1]
    """
    specifies underlining with a single line.
    """
    DOUBLE: Literal[2]
    """
    specifies underlining with a double line.
    """
    DOTTED: Literal[3]
    """
    specifies underlining with a dotted line.
    """
    DONTKNOW: Literal[4]
    """
    The kind of underlining is not known.
    """
    DASH: Literal[5]
    """
    specifies underlining with a dashed line.
    """
    LONGDASH: Literal[6]
    """
    specifies underlining with long dashes.
    """
    DASHDOT: Literal[7]
    """
    specifies underlining with a dash and dot sequence.
    """
    DASHDOTDOT: Literal[8]
    """
    specifies underlining with a dash, dot, dot sequence.
    """
    SMALLWAVE: Literal[9]
    """
    specifies underlining with a small wave.
    """
    WAVE: Literal[10]
    """
    specifies underlining with a wave.
    """
    DOUBLEWAVE: Literal[11]
    """
    specifies underlining with a double wave.
    """
    BOLD: Literal[12]
    """
    specifies underlining with a bold line.
    """
    BOLDDOTTED: Literal[13]
    """
    specifies underlining with bold dots.
    """
    BOLDDASH: Literal[14]
    """
    specifies underlining with bold dashes.
    """
    BOLDLONGDASH: Literal[15]
    """
    specifies underlining with long bold dashes.
    """
    BOLDDASHDOT: Literal[16]
    """
    specifies underlining with a dash and dot sequence in bold.
    """
    BOLDDASHDOTDOT: Literal[17]
    """
    specifies underlining with a dash, dot, dot sequence in bold.
    """
    BOLDWAVE: Literal[18]
    """
    specifies underlining with a bold wave.
    """

