# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API WrapTextMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0ae>`_
"""

DYNAMIC: 'uno.Enum'
"""
text flow depends on the situation.

The text formatting decides the best way.
"""
LEFT: 'uno.Enum'
"""
the object is left adjusted.

text flows to the left side of the object.

adjusted to the left.
"""
NONE: 'uno.Enum'
"""
text does not flow around the object.
"""
PARALLEL: 'uno.Enum'
"""
text flows to the left and right of the object.
"""
RIGHT: 'uno.Enum'
"""
the object is right adjusted.

text flows to the right side of the object.

adjusted to the right.
"""
THROUGH: 'uno.Enum'
"""
text flow ignores the object.
"""
THROUGHT: 'uno.Enum'
"""
text flow ignores the object: errant spelling deprecated in version 5.4
"""

