# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
"""
Const


See Also:
    `API TransitionSubType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html>`_
"""
DEFAULT: Literal[0]
LEFTTORIGHT: Literal[1]
TOPTOBOTTOM: Literal[2]
TOPLEFT: Literal[3]
TOPRIGHT: Literal[4]
BOTTOMRIGHT: Literal[5]
BOTTOMLEFT: Literal[6]
TOPCENTER: Literal[7]
RIGHTCENTER: Literal[8]
BOTTOMCENTER: Literal[9]
LEFTCENTER: Literal[10]
CORNERSIN: Literal[11]
CORNERSOUT: Literal[12]
VERTICAL: Literal[13]
HORIZONTAL: Literal[14]
DIAGONALBOTTOMLEFT: Literal[15]
DIAGONALTOPLEFT: Literal[16]
DOUBLEBARNDOOR: Literal[17]
DOUBLEDIAMOND: Literal[18]
DOWN: Literal[19]
LEFT: Literal[20]
UP: Literal[21]
RIGHT: Literal[22]
RECTANGLE: Literal[25]
DIAMOND: Literal[26]
CIRCLE: Literal[27]
FOURPOINT: Literal[28]
FIVEPOINT: Literal[29]
SIXPOINT: Literal[30]
HEART: Literal[31]
KEYHOLE: Literal[32]
CLOCKWISETWELVE: Literal[33]
CLOCKWISETHREE: Literal[34]
CLOCKWISESIX: Literal[35]
CLOCKWISENINE: Literal[36]
TWOBLADEVERTICAL: Literal[37]
TWOBLADEHORIZONTAL: Literal[38]
FOURBLADE: Literal[39]
CLOCKWISETOP: Literal[40]
CLOCKWISERIGHT: Literal[41]
CLOCKWISEBOTTOM: Literal[42]
CLOCKWISELEFT: Literal[43]
CLOCKWISETOPLEFT: Literal[44]
COUNTERCLOCKWISEBOTTOMLEFT: Literal[45]
CLOCKWISEBOTTOMRIGHT: Literal[46]
COUNTERCLOCKWISETOPRIGHT: Literal[47]
CENTERTOP: Literal[48]
CENTERRIGHT: Literal[49]
TOP: Literal[50]
BOTTOM: Literal[52]
FANOUTVERTICAL: Literal[54]
FANOUTHORIZONTAL: Literal[55]
FANINVERTICAL: Literal[56]
FANINHORIZONTAL: Literal[57]
PARALLELVERTICAL: Literal[58]
PARALLELDIAGONAL: Literal[59]
OPPOSITEVERTICAL: Literal[60]
OPPOSITEHORIZONTAL: Literal[61]
PARALLELDIAGONALTOPLEFT: Literal[62]
PARALLELDIAGONALBOTTOMLEFT: Literal[63]
TOPLEFTHORIZONTAL: Literal[64]
TOPLEFTDIAGONAL: Literal[65]
TOPRIGHTDIAGONAL: Literal[66]
BOTTOMRIGHTDIAGONAL: Literal[67]
BOTTOMLEFTDIAGONAL: Literal[68]
TOPLEFTCLOCKWISE: Literal[69]
TOPRIGHTCLOCKWISE: Literal[70]
BOTTOMRIGHTCLOCKWISE: Literal[71]
BOTTOMLEFTCLOCKWISE: Literal[72]
TOPLEFTCOUNTERCLOCKWISE: Literal[73]
TOPRIGHTCOUNTERCLOCKWISE: Literal[74]
BOTTOMRIGHTCOUNTERCLOCKWISE: Literal[75]
BOTTOMLEFTCOUNTERCLOCKWISE: Literal[76]
VERTICALTOPSAME: Literal[77]
VERTICALBOTTOMSAME: Literal[78]
VERTICALTOPLEFTOPPOSITE: Literal[79]
VERTICALBOTTOMLEFTOPPOSITE: Literal[80]
HORIZONTALLEFTSAME: Literal[81]
HORIZONTALRIGHTSAME: Literal[82]
HORIZONTALTOPLEFTOPPOSITE: Literal[83]
HORIZONTALTOPRIGHTOPPOSITE: Literal[84]
DIAGONALBOTTOMLEFTOPPOSITE: Literal[85]
DIAGONALTOPLEFTOPPOSITE: Literal[86]
TWOBOXTOP: Literal[87]
TWOBOXBOTTOM: Literal[88]
TWOBOXLEFT: Literal[89]
TWOBOXRIGHT: Literal[90]
FOURBOXVERTICAL: Literal[91]
FOURBOXHORIZONTAL: Literal[92]
VERTICALLEFT: Literal[93]
VERTICALRIGHT: Literal[94]
HORIZONTALLEFT: Literal[95]
HORIZONTALRIGHT: Literal[96]
FROMLEFT: Literal[97]
FROMTOP: Literal[98]
FROMRIGHT: Literal[99]
FROMBOTTOM: Literal[100]
CROSSFADE: Literal[101]
FADETOCOLOR: Literal[102]
FADEFROMCOLOR: Literal[103]
FADEOVERCOLOR: Literal[104]
THREEBLADE: Literal[105]
EIGHTBLADE: Literal[106]
ONEBLADE: Literal[107]
ACROSS: Literal[108]
TOPLEFTVERTICAL: Literal[109]
COMBHORIZONTAL: Literal[110]
COMBVERTICAL: Literal[111]
IN: Literal[112]
OUT: Literal[113]
ROTATEIN: Literal[114]
ROTATEOUT: Literal[115]
FROMTOPLEFT: Literal[116]
FROMTOPRIGHT: Literal[117]
FROMBOTTOMLEFT: Literal[118]
FROMBOTTOMRIGHT: Literal[119]

