# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the general kind of font.

They may be expanded in future versions.

See Also:
    `API FontFamily <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontFamily.html>`_
"""
DONTKNOW: Literal[0]
"""
specifies an unknown font family.
"""
DECORATIVE: Literal[1]
"""
specifies the family of decorative fonts.
"""
MODERN: Literal[2]
"""
specifies the family of modern fonts.
"""
ROMAN: Literal[3]
"""
specifies the family roman fonts (with serifs).
"""
SCRIPT: Literal[4]
"""
specifies the family of script fonts.
"""
SWISS: Literal[5]
"""
specifies the family roman fonts (without serifs).
"""
SYSTEM: Literal[6]
"""
specifies the family system fonts.
"""

