# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from .x_sheet_cell_range import XSheetCellRange as XSheetCellRange_e09d0cdf
if typing.TYPE_CHECKING:
    from .x_sheet_cell_cursor import XSheetCellCursor as XSheetCellCursor_ee400d70

class XSpreadsheet(XSheetCellRange_e09d0cdf):
    """
    provides methods to create a cell range cursor.

    See Also:
        `API XSpreadsheet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheet.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XSpreadsheet']

    def createCursor(self) -> 'XSheetCellCursor_ee400d70':
        """
        creates a cell cursor including the whole spreadsheet.
        """
    def createCursorByRange(self, aRange: 'XSheetCellRange_e09d0cdf') -> 'XSheetCellCursor_ee400d70':
        """
        creates a cell cursor to travel in the given range context.
        """

