# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from .x_label_range import XLabelRange as XLabelRange_af090b46

class LabelRange(XLabelRange_af090b46):
    """
    Service Class

    represents a cell area that contains labels and values related to the labels.
    
    Label ranges can be used in formulas to refer to cells in cell ranges with row or column titles. The formula uses the cell value that is related to the specified row or column title.

    See Also:
        `API LabelRange <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRange.html>`_
    """


