# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.presentation
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..container.x_named import XNamed as XNamed_a6520b08

class CustomPresentation(XIndexContainer_1c040ebe, XNamed_a6520b08):
    """
    Service Class

    A custom presentation can show the pages of its presentation in a customized order.
    
    Such a presentation can use certain pages more than once, but it does not necessarily use all of the pages.

    See Also:
        `API CustomPresentation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1CustomPresentation.html>`_
    """


