# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
"""
Const

The ShadingPattern determines the background color pattern against which characters and graphics are displayed, typically in tables.

The color can be no color or it can be a specific color with a transparency or pattern value.

See Also:
    `API ShadingPattern <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html>`_
"""
CLEAR: Literal[0]
SOLID: Literal[1]
PCT5: Literal[2]
PCT10: Literal[3]
PCT20: Literal[4]
PCT25: Literal[5]
PCT30: Literal[6]
PCT40: Literal[7]
PCT50: Literal[8]
PCT60: Literal[9]
PCT70: Literal[10]
PCT75: Literal[11]
PCT80: Literal[12]
PCT90: Literal[13]
HORZ_STRIPE: Literal[14]
VERT_STRIPE: Literal[15]
REVERSE_DIAG_STRIPE: Literal[16]
DIAG_STRIPE: Literal[17]
HORZ_CROSS: Literal[18]
DIAG_CROSS: Literal[19]
THIN_HORZ_STRIPE: Literal[20]
THIN_VERT_STRIPE: Literal[21]
THIN_REVERSE_DIAG_STRIPE: Literal[22]
THIN_DIAG_STRIPE: Literal[23]
THIN_HORZ_CROSS: Literal[24]
THIN_DIAG_CROSS: Literal[25]
UNUSED_1: Literal[26]
UNUSED_2: Literal[27]
UNUSED_3: Literal[28]
UNUSED_4: Literal[29]
UNUSED_5: Literal[30]
UNUSED_6: Literal[31]
UNUSED_7: Literal[32]
UNUSED_8: Literal[33]
UNUSED_9: Literal[34]
PCT2: Literal[35]
PCT7: Literal[36]
PCT12: Literal[37]
PCT15: Literal[38]
PCT17: Literal[39]
PCT22: Literal[40]
PCT27: Literal[41]
PCT32: Literal[42]
PCT35: Literal[43]
PCT37: Literal[44]
PCT42: Literal[45]
PCT45: Literal[46]
PCT47: Literal[47]
PCT52: Literal[48]
PCT55: Literal[49]
PCT57: Literal[50]
PCT62: Literal[51]
PCT65: Literal[52]
PCT67: Literal[53]
PCT72: Literal[54]
PCT77: Literal[55]
PCT82: Literal[56]
PCT85: Literal[57]
PCT87: Literal[58]
PCT92: Literal[59]
PCT95: Literal[60]
PCT97: Literal[61]
NIL: Literal[65535]

