# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_content import XContent as XContent_79db0975
    from .x_content_identifier import XContentIdentifier as XContentIdentifier_edc90d78

class XContentProvider(XInterface_8f010a43):
    """
    a content provider which creates and manages XContents.

    See Also:
        `API XContentProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XContentProvider']

    def compareContentIds(self, Id1: 'XContentIdentifier_edc90d78', Id2: 'XContentIdentifier_edc90d78') -> int:
        """
        compares two XContentIdentifiers.
        """
    def queryContent(self, Identifier: 'XContentIdentifier_edc90d78') -> 'XContent_79db0975':
        """
        creates a new XContent instance, if the given XContentIdentifier matches a content provided by the implementation of this interface.

        Raises:
            com.sun.star.ucb.IllegalIdentifierException: ``IllegalIdentifierException``
        """

