# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ..._pyi.datatransfer.clipboard.clipboard_event import ClipboardEvent as ClipboardEvent
from ..._pyi.datatransfer.clipboard.clipboard_manager import ClipboardManager as ClipboardManager
from ..._pyi.datatransfer.clipboard.generic_clipboard import GenericClipboard as GenericClipboard
from ..._pyi.datatransfer.clipboard.system_clipboard import SystemClipboard as SystemClipboard
from ..._pyi.datatransfer.clipboard.x_clipboard import XClipboard as XClipboard
from ..._pyi.datatransfer.clipboard.x_clipboard_ex import XClipboardEx as XClipboardEx
from ..._pyi.datatransfer.clipboard.x_clipboard_factory import XClipboardFactory as XClipboardFactory
from ..._pyi.datatransfer.clipboard.x_clipboard_listener import XClipboardListener as XClipboardListener
from ..._pyi.datatransfer.clipboard.x_clipboard_manager import XClipboardManager as XClipboardManager
from ..._pyi.datatransfer.clipboard.x_clipboard_notifier import XClipboardNotifier as XClipboardNotifier
from ..._pyi.datatransfer.clipboard.x_clipboard_owner import XClipboardOwner as XClipboardOwner
from ..._pyi.datatransfer.clipboard.x_flushable_clipboard import XFlushableClipboard as XFlushableClipboard
from ..._pyi.datatransfer.clipboard.x_system_clipboard import XSystemClipboard as XSystemClipboard
