# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the width of the characters of a font.

They may be expanded in future versions.

See Also:
    `API FontWidth <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontWidth.html>`_
"""
DONTKNOW: float
"""
The width of the font is not specified/known.
"""
ULTRACONDENSED: float
"""
The width of the font is condensed to 50%.
"""
EXTRACONDENSED: float
"""
The width of the font is condensed to 60%.
"""
CONDENSED: float
"""
The width of the font is condensed to 75%.
"""
SEMICONDENSED: float
"""
The width of the font is condensed to 90%.
"""
NORMAL: float
"""
The width of the font is normal.
"""
SEMIEXPANDED: float
"""
The width of the font is expanded to 110%.
"""
EXPANDED: float
"""
The width of the font is expanded to 150%.
"""
EXTRAEXPANDED: float
"""
The width of the font is expanded to 175%.
"""
ULTRAEXPANDED: float
"""
The width of the font is expanded to 200%.
"""

