# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class UserDataPart(object):
    """
    Const

    These constants define which part of the user data is displayed in a user data text field (service \"sun.one.text.TextField.ExtendedUser\")

    See Also:
        `API UserDataPart <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html>`_
    """
    COMPANY: Literal[0]
    """
    The field shows the company name.
    """
    FIRSTNAME: Literal[1]
    """
    The field shows the first name.
    """
    NAME: Literal[2]
    """
    The field shows the name.
    """
    SHORTCUT: Literal[3]
    """
    The field shows the initials.
    """
    STREET: Literal[4]
    """
    The field shows the street.
    """
    COUNTRY: Literal[5]
    """
    The field shows the country.
    """
    ZIP: Literal[6]
    """
    The field shows the zip code.
    """
    CITY: Literal[7]
    """
    The field shows the city.
    """
    TITLE: Literal[8]
    """
    The field shows the title.
    """
    POSITION: Literal[9]
    """
    The field shows the position.
    """
    PHONE_PRIVATE: Literal[10]
    """
    The field shows the no of the private phone.
    """
    PHONE_COMPANY: Literal[11]
    """
    The field shows the number of the business phone.
    """
    FAX: Literal[12]
    """
    The field shows the fax no.
    """
    EMAIL: Literal[13]
    """
    The field shows the e-Mail.
    """
    STATE: Literal[14]
    """
    The field shows the state.
    """

