# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API OutgoingMessageState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a8dec3ee1933cc93724b3764b124b8cc1>`_
"""

COMPLETELY_LOCALLY_SENT: 'uno.Enum'
"""
Message has been sent upstream to all recipients.
"""
CONFIRMED: 'uno.Enum'
"""
Recipient confirmed reading.
"""
EXTERNAL_ERROR: 'uno.Enum'
"""
Global fatal error (e.g.

last member in SMTP chain could not deliver the message).
"""
NONRECOVERABLE_LOCAL_ERROR: 'uno.Enum'
"""
Local fatal error (e.g.

first SMTP server upstream did not accept the message).
"""
PARTIALLY_LOCALLY_SENT: 'uno.Enum'
"""
Message has been sent upstream to some recipients.
"""
RECOVERABLE_LOCAL_ERROR: 'uno.Enum'
"""
Local, non-fatal error (e.g.

network temporarily not available).
"""
WAITING_CONFIRMATION: 'uno.Enum'
"""
Message was sent; we are waiting for confirmation.
"""
WRITTEN: 'uno.Enum'
"""
Message has just been placed into the out tray.
"""

