# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing.framework
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_resource import XResource as XResource_3bcd0f90
    from .x_resource_id import XResourceId as XResourceId_5be3103d

class XResourceFactory(ABC):
    """
    Factory and possibly cache for creating and releasing resources.
    
    A resource factory is created and used by the XConfigurationController object.
    
    A factory may want to implement a cache to reuse previously released resources.

    See Also:
        `API XResourceFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XResourceFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.framework.XResourceFactory']

    def createResource(self, xResourceId: 'XResourceId_5be3103d') -> 'XResource_3bcd0f90':
        """
        Create a resource for the given XResourceId object.
        
        Valid values are those for which the factory has previously been registered at the XConfigurationController
        
        .

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def releaseResource(self, xResource: 'XResource_3bcd0f90') -> None:
        """
        Call this method to tell a factory that the given resource is no longer in use.
        
        The factory can decide whether to destroy the resource or to keep it in a cache in order to reuse it later.
        """

