# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..rdf.x_metadatable import XMetadatable as XMetadatable_a3000af0
from .text_content import TextContent as TextContent_a6810b4d

class InContentMetadata(TextContent_a6810b4d, XChild_a6390b07, XEnumerationAccess_4bac0ffc, XMetadatable_a3000af0):
    """
    Service Class

    is a TextContent that can be used to attach RDF metadata to a range of text.
    
    **since**
    
        OOo 3.2

    See Also:
        `API InContentMetadata <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1InContentMetadata.html>`_
    """


