# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart
from .x_axis_x_supplier import XAxisXSupplier as XAxisXSupplier_d43a0cb3

class ChartAxisXSupplier(XAxisXSupplier_d43a0cb3):
    """
    Service Class

    has to be supported by charts providing the capabilities of a horizontal axis, i.e., an x-axis.

    See Also:
        `API ChartAxisXSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxisXSupplier.html>`_
    """
    @property
    def HasXAxis(self) -> bool:
        """
        This property determines if the x-axis is shown or hidden.
        """
    @property
    def HasXAxisDescription(self) -> bool:
        """
        Determines if the description of the x-axis is shown or hidden.
        """
    @property
    def HasXAxisGrid(self) -> bool:
        """
        Determines if the major grid of the x-axis is shown or hidden.
        """
    @property
    def HasXAxisHelpGrid(self) -> bool:
        """
        Determines if the minor grid of the x-axis is shown or hidden.
        """
    @property
    def HasXAxisTitle(self) -> bool:
        """
        Determines if the title of the x-axis is shown or hidden.
        """


