# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal


class CommandType(object):
    """
    Const

    indicates the type of a command.

    See Also:
        `API CommandType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1CommandType.html>`_
    """
    TABLE: Literal[0]
    """
    indicates that a command contains a table name, which can be used to process a command like \"select * from tablename\".
    """
    QUERY: Literal[1]
    """
    indicates that a command contains a name of a query component, which contains a certain statement.
    """
    COMMAND: Literal[2]
    """
    indicates that the command is an SQL-Statement.
    """

