# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class ConfigurationProvider(XComponent_98dc0ab5, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    manages one, or more, complete sets of configuration data and serves as a factory for objects that provide access to a subset of the configuration.
    
    An implementation is usually obtained from a com.sun.star.lang.ServiceManager. The arguments passed to com.sun.star.lang.XMultiComponentFactory.createInstanceWithArgumentsAndContext() select the configuration data source. Arguments must be provided as com.sun.star.beans.NamedValue or com.sun.star.beans.PropertyValue. If the parameters given are incomplete missing values are taken from the context or the environment. If an instance already exists for the given set of arguments, the existing instance may be reused. In particular, instantiating a provider without explicit arguments to access the default configuration data will always yield the same com.sun.star.configuration.DefaultProvider object.
    
    Some arguments for com.sun.star.lang.XMultiServiceFactory.createInstanceWithArguments() may be given default values during creation of this service. In particular this applies to the parameters \"Locale\" and \"EnableAsync\".
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API ConfigurationProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1ConfigurationProvider.html>`_
    """


