# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..container.x_named import XNamed as XNamed_a6520b08

class TableAutoFormat(XPropertySet_bc180bfa, XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XNamed_a6520b08):
    """
    Service Class

    represents an AutoFormat, containing exactly 16 AutoFormat fields.
    
    Each of the 16 fields contain formatting properties for a table cell at a specific position in the AutoFormat range. The rows of the range are divided into a header row, a footer row and 2 data rows (repeated in turn between header and footer row). The columns are divided similar. This results in 16 different types of cells in the range. The AutoFormats are numbered row by row, then column by column.

    See Also:
        `API TableAutoFormat <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormat.html>`_
    """
    @property
    def IncludeBackground(self) -> bool:
        """
        specifies whether the background settings from the fields are used.
        """
    @property
    def IncludeBorder(self) -> bool:
        """
        specifies whether the border settings from the fields are used.
        """
    @property
    def IncludeFont(self) -> bool:
        """
        specifies whether the font settings from the fields are used.
        """
    @property
    def IncludeJustify(self) -> bool:
        """
        specifies whether the justification settings from the fields are used.
        """
    @property
    def IncludeNumberFormat(self) -> bool:
        """
        specifies whether the number format settings from the fields are used.
        """
    @property
    def IncludeWidthAndHeight(self) -> bool:
        """
        specifies whether the column widths and row heights should be updated after applying the format.
        """


