# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XCalculatable(XInterface_8f010a43):
    """
    represents something that can recalculate.

    See Also:
        `API XCalculatable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCalculatable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XCalculatable']

    def calculate(self) -> None:
        """
        recalculates all dirty cells.
        
        This calculates all formula cells which have not yet been calculated after their precedents have changed.
        """
    def calculateAll(self) -> None:
        """
        recalculates all cells.
        """
    def enableAutomaticCalculation(self, bEnabled: bool) -> None:
        """
        enables automatic calculation.
        
        With automatic calculation, each formula cell is recalculated whenever its value is needed after its precedents have changed. The value is needed if the cell is displayed or used in another calculation.
        """
    def isAutomaticCalculationEnabled(self) -> bool:
        """
        returns whether automatic calculation is enabled.
        
        With automatic calculation, each formula cell is recalculated whenever its value is needed after its precedents have changed. The value is needed if the cell is displayed or used in another calculation.
        """

