# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..frame.controller import Controller as Controller_a5330b37
from .spreadsheet_view_pane import SpreadsheetViewPane as SpreadsheetViewPane_1c0b0eb8
from .spreadsheet_view_settings import SpreadsheetViewSettings as SpreadsheetViewSettings_5bbd1085
from .x_activation_broadcaster import XActivationBroadcaster as XActivationBroadcaster_48ce0ff5
from .x_enhanced_mouse_click_broadcaster import XEnhancedMouseClickBroadcaster as XEnhancedMouseClickBroadcaster_d16c12e8
from .x_range_selection import XRangeSelection as XRangeSelection_e1310d0c
from .x_spreadsheet_view import XSpreadsheetView as XSpreadsheetView_f0290d8c
from .x_view_freezable import XViewFreezable as XViewFreezable_d4d40ca4
from .x_view_splitable import XViewSplitable as XViewSplitable_d5640cb4
from ..view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15

class SpreadsheetView(Controller_a5330b37, SpreadsheetViewPane_1c0b0eb8, SpreadsheetViewSettings_5bbd1085, XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XActivationBroadcaster_48ce0ff5, XEnhancedMouseClickBroadcaster_d16c12e8, XRangeSelection_e1310d0c, XSpreadsheetView_f0290d8c, XViewFreezable_d4d40ca4, XViewSplitable_d5640cb4, XSelectionSupplier_fed20e15):
    """
    Service Class

    represents a view of a spreadsheet document.

    See Also:
        `API SpreadsheetView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetView.html>`_
    """


