# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class FieldUnit(object):
    """
    Const

    specifies attributes for the MetricField map units.
    
    IMPORTANT: These constants have to be disjunct with constants in util/MeasureUnit.

    See Also:
        `API FieldUnit <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html>`_
    """
    FUNIT_NONE: Literal[0]
    FUNIT_MM: Literal[1]
    FUNIT_CM: Literal[2]
    FUNIT_M: Literal[3]
    FUNIT_KM: Literal[4]
    FUNIT_TWIP: Literal[5]
    FUNIT_POINT: Literal[6]
    FUNIT_PICA: Literal[7]
    FUNIT_INCH: Literal[8]
    FUNIT_FOOT: Literal[9]
    FUNIT_MILE: Literal[10]
    FUNIT_CUSTOM: Literal[11]
    FUNIT_PERCENT: Literal[12]
    FUNIT_100TH_MM: Literal[13]

