# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal


class DataPilotTablePositionType(object):
    """
    Const

    specifies in which sub-area a cell is positioned within a DataPilot table.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotTablePositionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html>`_
    """
    NOT_IN_TABLE: Literal[0]
    """
    indicates that the specified cell is not in the DataPilot table.
    """
    RESULT: Literal[1]
    """
    indicates that the specified cell is within the result area.
    """
    ROW_HEADER: Literal[2]
    """
    indicates that the specified cell is within the row header area.
    """
    COLUMN_HEADER: Literal[3]
    """
    indicates that the specified cell is within the column header area.
    """
    OTHER: Literal[4]
    """
    indicates that the specified cell is within the table but in areas other than the result or header areas.
    """

