# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.scanner
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class ScanError(Enum):
    """
    Enum

    

    See Also:
        `API ScanError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1scanner.html#abd1619ea132004db8599d9529755e9ab>`_
    """

    InvalidContext: 'uno.Enum'
    """
    InvalidContext: a device was requested that does not exist.
    """
    ScanCanceled: 'uno.Enum'
    """
    ScanCanceled: the scan was canceled by the user.
    """
    ScanErrorNone: 'uno.Enum'
    """
    ScanErrorNone: no error occurred.
    """
    ScanFailed: 'uno.Enum'
    """
    ScanFailed: an error occurred during scanning.
    """
    ScanInProgress: 'uno.Enum'
    """
    ScanInProgress: a scan is already in progress on this device that has to end before a new one can be started.
    """
    ScannerNotAvailable: 'uno.Enum'
    """
    ScannerNotAvailable: the requested device could not be opened.
    """

