# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..script.x_storage_based_library_container import XStorageBasedLibraryContainer as XStorageBasedLibraryContainer_d72a1321

class XEmbeddedScripts(ABC):
    """
    is supported by OfficeDocuments which allow to embed scripts
    
    **since**
    
        OOo 2.4

    See Also:
        `API XEmbeddedScripts <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XEmbeddedScripts.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XEmbeddedScripts']

    @property
    def AllowMacroExecution(self) -> bool:
        """
        determines whether executing macros from this document is allowed.
        
        Effectively, this attribute is an evaluation of the document's MacroExecMode against possibly applicable configuration settings, the document location in relation to the trusted location, and the like.
        """

    @property
    def BasicLibraries(self) -> 'XStorageBasedLibraryContainer_d72a1321':
        """
        is the container of StarBasic macro libraries contained in the document
        """

    @property
    def DialogLibraries(self) -> 'XStorageBasedLibraryContainer_d72a1321':
        """
        is the container of dialogs libraries contained in the document
        """


