# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .homogen_matrix_line import HomogenMatrixLine as HomogenMatrixLine_1c250ebe


class HomogenMatrix(object):
    """
    Struct Class

    specifies a homogeneous matrix by three homogeneous lines

    See Also:
        `API HomogenMatrix <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix.html>`_
    """
    typeName: Literal['com.sun.star.drawing.HomogenMatrix']

    def __init__(self, Line1: typing.Optional[HomogenMatrixLine_1c250ebe] = ..., Line2: typing.Optional[HomogenMatrixLine_1c250ebe] = ..., Line3: typing.Optional[HomogenMatrixLine_1c250ebe] = ..., Line4: typing.Optional[HomogenMatrixLine_1c250ebe] = ...) -> None:
        """
        Constructor

        Arguments:
            Line1 (HomogenMatrixLine, optional): Line1 value.
            Line2 (HomogenMatrixLine, optional): Line2 value.
            Line3 (HomogenMatrixLine, optional): Line3 value.
            Line4 (HomogenMatrixLine, optional): Line4 value.
        """


    @property
    def Line1(self) -> HomogenMatrixLine_1c250ebe:
        ...


    @property
    def Line2(self) -> HomogenMatrixLine_1c250ebe:
        ...


    @property
    def Line3(self) -> HomogenMatrixLine_1c250ebe:
        ...


    @property
    def Line4(self) -> HomogenMatrixLine_1c250ebe:
        ...


