# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.drawing.accessible_draw_document_view import AccessibleDrawDocumentView as AccessibleDrawDocumentView
from .._pyi.drawing.accessible_graph_control import AccessibleGraphControl as AccessibleGraphControl
from .._pyi.drawing.accessible_graphic_shape import AccessibleGraphicShape as AccessibleGraphicShape
from .._pyi.drawing.accessible_image_bullet import AccessibleImageBullet as AccessibleImageBullet
from .._pyi.drawing.accessible_ole_shape import AccessibleOLEShape as AccessibleOLEShape
from .._pyi.drawing.accessible_shape import AccessibleShape as AccessibleShape
from .._pyi.drawing.accessible_slide_view import AccessibleSlideView as AccessibleSlideView
from .._pyi.drawing.accessible_slide_view_object import AccessibleSlideViewObject as AccessibleSlideViewObject
from .._pyi.drawing.applet_shape import AppletShape as AppletShape
from .._pyi.drawing.background import Background as Background
from .._pyi.drawing.bezier_point import BezierPoint as BezierPoint
from .._pyi.drawing.bitmap_table import BitmapTable as BitmapTable
from .._pyi.drawing.bound_volume import BoundVolume as BoundVolume
from .._pyi.drawing.camera_geometry import CameraGeometry as CameraGeometry
from .._pyi.drawing.caption_shape import CaptionShape as CaptionShape
from .._pyi.drawing.closed_bezier_shape import ClosedBezierShape as ClosedBezierShape
from .._pyi.drawing.color_table import ColorTable as ColorTable
from .._pyi.drawing.connector_properties import ConnectorProperties as ConnectorProperties
from .._pyi.drawing.connector_shape import ConnectorShape as ConnectorShape
from .._pyi.drawing.control_shape import ControlShape as ControlShape
from .._pyi.drawing.coordinate_sequence import CoordinateSequence as CoordinateSequence
from .._pyi.drawing.coordinate_sequence_sequence import CoordinateSequenceSequence as CoordinateSequenceSequence
from .._pyi.drawing.custom_shape import CustomShape as CustomShape
from .._pyi.drawing.custom_shape_engine import CustomShapeEngine as CustomShapeEngine
from .._pyi.drawing.dash_table import DashTable as DashTable
from .._pyi.drawing.defaults import Defaults as Defaults
from .._pyi.drawing.direction3_d import Direction3D as Direction3D
from .._pyi.drawing.document_settings import DocumentSettings as DocumentSettings
from .._pyi.drawing.double_sequence import DoubleSequence as DoubleSequence
from .._pyi.drawing.double_sequence_sequence import DoubleSequenceSequence as DoubleSequenceSequence
from .._pyi.drawing.draw_page import DrawPage as DrawPage
from .._pyi.drawing.draw_pages import DrawPages as DrawPages
from .._pyi.drawing.drawing_document import DrawingDocument as DrawingDocument
from .._pyi.drawing.drawing_document_draw_view import DrawingDocumentDrawView as DrawingDocumentDrawView
from .._pyi.drawing.drawing_document_factory import DrawingDocumentFactory as DrawingDocumentFactory
from .._pyi.drawing.ellipse_shape import EllipseShape as EllipseShape
from .._pyi.drawing.enhanced_custom_shape_adjustment_value import EnhancedCustomShapeAdjustmentValue as EnhancedCustomShapeAdjustmentValue
from .._pyi.drawing.enhanced_custom_shape_extrusion import EnhancedCustomShapeExtrusion as EnhancedCustomShapeExtrusion
from .._pyi.drawing.enhanced_custom_shape_geometry import EnhancedCustomShapeGeometry as EnhancedCustomShapeGeometry
from .._pyi.drawing.enhanced_custom_shape_handle import EnhancedCustomShapeHandle as EnhancedCustomShapeHandle
from .._pyi.drawing.enhanced_custom_shape_parameter import EnhancedCustomShapeParameter as EnhancedCustomShapeParameter
from .._pyi.drawing.enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair
from .._pyi.drawing.enhanced_custom_shape_path import EnhancedCustomShapePath as EnhancedCustomShapePath
from .._pyi.drawing.enhanced_custom_shape_segment import EnhancedCustomShapeSegment as EnhancedCustomShapeSegment
from .._pyi.drawing.enhanced_custom_shape_text_frame import EnhancedCustomShapeTextFrame as EnhancedCustomShapeTextFrame
from .._pyi.drawing.enhanced_custom_shape_text_path import EnhancedCustomShapeTextPath as EnhancedCustomShapeTextPath
from .._pyi.drawing.fill_properties import FillProperties as FillProperties
from .._pyi.drawing.flag_sequence import FlagSequence as FlagSequence
from .._pyi.drawing.flag_sequence_sequence import FlagSequenceSequence as FlagSequenceSequence
from .._pyi.drawing.generic_draw_page import GenericDrawPage as GenericDrawPage
from .._pyi.drawing.generic_drawing_document import GenericDrawingDocument as GenericDrawingDocument
from .._pyi.drawing.glue_point import GluePoint as GluePoint
from .._pyi.drawing.glue_point2 import GluePoint2 as GluePoint2
from .._pyi.drawing.gradient_table import GradientTable as GradientTable
from .._pyi.drawing.graphic_export_filter import GraphicExportFilter as GraphicExportFilter
from .._pyi.drawing.graphic_filter_request import GraphicFilterRequest as GraphicFilterRequest
from .._pyi.drawing.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
from .._pyi.drawing.group_shape import GroupShape as GroupShape
from .._pyi.drawing.hatch import Hatch as Hatch
from .._pyi.drawing.hatch_table import HatchTable as HatchTable
from .._pyi.drawing.homogen_matrix import HomogenMatrix as HomogenMatrix
from .._pyi.drawing.homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3
from .._pyi.drawing.homogen_matrix4 import HomogenMatrix4 as HomogenMatrix4
from .._pyi.drawing.homogen_matrix_line import HomogenMatrixLine as HomogenMatrixLine
from .._pyi.drawing.homogen_matrix_line3 import HomogenMatrixLine3 as HomogenMatrixLine3
from .._pyi.drawing.homogen_matrix_line4 import HomogenMatrixLine4 as HomogenMatrixLine4
from .._pyi.drawing.layer import Layer as Layer
from .._pyi.drawing.layer_manager import LayerManager as LayerManager
from .._pyi.drawing.line_dash import LineDash as LineDash
from .._pyi.drawing.line_properties import LineProperties as LineProperties
from .._pyi.drawing.line_shape import LineShape as LineShape
from .._pyi.drawing.marker_table import MarkerTable as MarkerTable
from .._pyi.drawing.master_page import MasterPage as MasterPage
from .._pyi.drawing.master_pages import MasterPages as MasterPages
from .._pyi.drawing.measure_properties import MeasureProperties as MeasureProperties
from .._pyi.drawing.measure_shape import MeasureShape as MeasureShape
from .._pyi.drawing.module_dispatcher import ModuleDispatcher as ModuleDispatcher
from .._pyi.drawing.ole2_shape import OLE2Shape as OLE2Shape
from .._pyi.drawing.open_bezier_shape import OpenBezierShape as OpenBezierShape
from .._pyi.drawing.page_shape import PageShape as PageShape
from .._pyi.drawing.plugin_shape import PluginShape as PluginShape
from .._pyi.drawing.point_sequence import PointSequence as PointSequence
from .._pyi.drawing.point_sequence_sequence import PointSequenceSequence as PointSequenceSequence
from .._pyi.drawing.poly_line_shape import PolyLineShape as PolyLineShape
from .._pyi.drawing.poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords
from .._pyi.drawing.poly_polygon_bezier_descriptor import PolyPolygonBezierDescriptor as PolyPolygonBezierDescriptor
from .._pyi.drawing.poly_polygon_bezier_shape import PolyPolygonBezierShape as PolyPolygonBezierShape
from .._pyi.drawing.poly_polygon_descriptor import PolyPolygonDescriptor as PolyPolygonDescriptor
from .._pyi.drawing.poly_polygon_shape import PolyPolygonShape as PolyPolygonShape
from .._pyi.drawing.poly_polygon_shape3_d import PolyPolygonShape3D as PolyPolygonShape3D
from .._pyi.drawing.position3_d import Position3D as Position3D
from .._pyi.drawing.qr_code import QRCode as QRCode
from .._pyi.drawing.rectangle_shape import RectangleShape as RectangleShape
from .._pyi.drawing.rotation_descriptor import RotationDescriptor as RotationDescriptor
from .._pyi.drawing.shadow_properties import ShadowProperties as ShadowProperties
from .._pyi.drawing.shape import Shape as Shape
from .._pyi.drawing.shape_collection import ShapeCollection as ShapeCollection
from .._pyi.drawing.shapes import Shapes as Shapes
from .._pyi.drawing.slide_renderer import SlideRenderer as SlideRenderer
from .._pyi.drawing.slide_sorter import SlideSorter as SlideSorter
from .._pyi.drawing.text import Text as Text
from .._pyi.drawing.text_properties import TextProperties as TextProperties
from .._pyi.drawing.text_shape import TextShape as TextShape
from .._pyi.drawing.transparency_gradient_table import TransparencyGradientTable as TransparencyGradientTable
from .._pyi.drawing.x_connectable_shape import XConnectableShape as XConnectableShape
from .._pyi.drawing.x_connector_shape import XConnectorShape as XConnectorShape
from .._pyi.drawing.x_control_shape import XControlShape as XControlShape
from .._pyi.drawing.x_custom_shape_engine import XCustomShapeEngine as XCustomShapeEngine
from .._pyi.drawing.x_custom_shape_handle import XCustomShapeHandle as XCustomShapeHandle
from .._pyi.drawing.x_draw_page import XDrawPage as XDrawPage
from .._pyi.drawing.x_draw_page_duplicator import XDrawPageDuplicator as XDrawPageDuplicator
from .._pyi.drawing.x_draw_page_expander import XDrawPageExpander as XDrawPageExpander
from .._pyi.drawing.x_draw_page_summarizer import XDrawPageSummarizer as XDrawPageSummarizer
from .._pyi.drawing.x_draw_page_supplier import XDrawPageSupplier as XDrawPageSupplier
from .._pyi.drawing.x_draw_pages import XDrawPages as XDrawPages
from .._pyi.drawing.x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier
from .._pyi.drawing.x_draw_sub_controller import XDrawSubController as XDrawSubController
from .._pyi.drawing.x_draw_view import XDrawView as XDrawView
from .._pyi.drawing.x_enhanced_custom_shape_defaulter import XEnhancedCustomShapeDefaulter as XEnhancedCustomShapeDefaulter
from .._pyi.drawing.x_glue_points_supplier import XGluePointsSupplier as XGluePointsSupplier
from .._pyi.drawing.x_graphic_export_filter import XGraphicExportFilter as XGraphicExportFilter
from .._pyi.drawing.x_layer import XLayer as XLayer
from .._pyi.drawing.x_layer_manager import XLayerManager as XLayerManager
from .._pyi.drawing.x_layer_supplier import XLayerSupplier as XLayerSupplier
from .._pyi.drawing.x_master_page_target import XMasterPageTarget as XMasterPageTarget
from .._pyi.drawing.x_master_pages_supplier import XMasterPagesSupplier as XMasterPagesSupplier
from .._pyi.drawing.x_presenter_helper import XPresenterHelper as XPresenterHelper
from .._pyi.drawing.x_selection_function import XSelectionFunction as XSelectionFunction
from .._pyi.drawing.x_shape import XShape as XShape
from .._pyi.drawing.x_shape_aligner import XShapeAligner as XShapeAligner
from .._pyi.drawing.x_shape_arranger import XShapeArranger as XShapeArranger
from .._pyi.drawing.x_shape_binder import XShapeBinder as XShapeBinder
from .._pyi.drawing.x_shape_combiner import XShapeCombiner as XShapeCombiner
from .._pyi.drawing.x_shape_descriptor import XShapeDescriptor as XShapeDescriptor
from .._pyi.drawing.x_shape_group import XShapeGroup as XShapeGroup
from .._pyi.drawing.x_shape_grouper import XShapeGrouper as XShapeGrouper
from .._pyi.drawing.x_shape_mirror import XShapeMirror as XShapeMirror
from .._pyi.drawing.x_shapes import XShapes as XShapes
from .._pyi.drawing.x_shapes2 import XShapes2 as XShapes2
from .._pyi.drawing.x_shapes3 import XShapes3 as XShapes3
from .._pyi.drawing.x_slide_preview_cache import XSlidePreviewCache as XSlidePreviewCache
from .._pyi.drawing.x_slide_preview_cache_listener import XSlidePreviewCacheListener as XSlidePreviewCacheListener
from .._pyi.drawing.x_slide_renderer import XSlideRenderer as XSlideRenderer
from .._pyi.drawing.x_slide_sorter_base import XSlideSorterBase as XSlideSorterBase
from .._pyi.drawing.x_universal_shape_descriptor import XUniversalShapeDescriptor as XUniversalShapeDescriptor
