# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API ContentCreationError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#aa2e437022c4d519cf5488a06e5e81ef4>`_
"""

CONTENT_CREATION_FAILED: 'uno.Enum'
"""
Provider was unable to create the content instance.
"""
IDENTIFIER_CREATION_FAILED: 'uno.Enum'
"""
Creation of content identifier failed.
"""
NO_CONTENT_BROKER: 'uno.Enum'
"""
"""
NO_CONTENT_PROVIDER: 'uno.Enum'
"""
No Content Provider for given content identifier available.
"""
NO_IDENTIFIER_FACTORY: 'uno.Enum'
"""
"""
UNKNOWN: 'uno.Enum'
"""
Unknown.

An unknown I/O error has occurred.
"""

