# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form
from ..awt.x_tab_controller import XTabController as XTabController_bacd0be7
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from .form_controller_dispatcher import FormControllerDispatcher as FormControllerDispatcher_5b3a107b
from .x_confirm_delete_broadcaster import XConfirmDeleteBroadcaster as XConfirmDeleteBroadcaster_6772109f
from .x_database_parameter_broadcaster import XDatabaseParameterBroadcaster as XDatabaseParameterBroadcaster_ac7f1234
from .x_form_controller import XFormController as XFormController_d4fc0ccc
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..sdb.x_row_set_approve_broadcaster import XRowSetApproveBroadcaster as XRowSetApproveBroadcaster_56601044
from ..sdb.xsql_error_broadcaster import XSQLErrorBroadcaster as XSQLErrorBroadcaster_4d10dfd
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0

class FormController(FormControllerDispatcher_5b3a107b, XConfirmDeleteBroadcaster_6772109f, XDatabaseParameterBroadcaster_ac7f1234, XFormController_d4fc0ccc, XTabController_bacd0be7, XChild_a6390b07, XEnumerationAccess_4bac0ffc, XComponent_98dc0ab5, XRowSetApproveBroadcaster_56601044, XSQLErrorBroadcaster_4d10dfd, XModifyBroadcaster_fd990df0):
    """
    Service Class

    is superseded by com.sun.star.form.runtime.FormController.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API FormController <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1FormController.html>`_
    """


